@@ -1,6 +1,5 @@
 package WWW::MenuGrinder::Plugin::YAMLLoader;
-our $VERSION = '0.01_01';
-
+our $VERSION = '0.04';
 
 # ABSTRACT: WWW::MenuGrinder plugin that loads menus with YAML::XS.
 
@@ -27,17 +26,21 @@ sub load {
 
 no Moose;
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 
 __END__
+=pod
+
 =head1 NAME
 
 WWW::MenuGrinder::Plugin::YAMLLoader - WWW::MenuGrinder plugin that loads menus with YAML::XS.
 
 =head1 VERSION
 
-version 0.01_01
+version 0.04
 
 =head1 DESCRIPTION
 
@@ -60,8 +63,10 @@ read.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by HBS Labs, LLC..
+This software is copyright (c) 2010 by HBS Labs, LLC..
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
