@@ -1,6 +1,5 @@
 package WWW::MenuGrinder::Role::Loader;
-our $VERSION = '0.01_01';
-
+our $VERSION = '0.04';
 
 # ABSTRACT: WWW::MenuGrinder role for plugins that load menu data.
 
@@ -8,6 +7,7 @@ use Moose::Role;
 
 with 'WWW::MenuGrinder::Role::Plugin';
 
+
 requires 'load';
 
 no Moose::Role;
@@ -15,13 +15,23 @@ no Moose::Role;
 1;
 
 __END__
+=pod
+
 =head1 NAME
 
 WWW::MenuGrinder::Role::Loader - WWW::MenuGrinder role for plugins that load menu data.
 
 =head1 VERSION
 
-version 0.01_01
+version 0.04
+
+=head1 METHODS
+
+=head2 C<< $plugin->load >>
+
+Is expected to return a menu structure ready for pre-mogrification. Data may
+come from disk, the network, attributes, or whatever. Takes no arguments, but
+C<< $self->grinder->config >> is available.
 
 =head1 AUTHOR
 
@@ -29,8 +39,10 @@ version 0.01_01
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by HBS Labs, LLC..
+This software is copyright (c) 2010 by HBS Labs, LLC..
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
